function l = claplacian(f,m)
% This function calculates the laplacian for a resistance function
% which is constant 1.
% 
% support functions: laplacian.m
%
% INPUT:
% f - function values in TLR order on an mth level SG graph
% m - level of restriction (size of f = 3^(m+1))
%
% OUTPUT: 
% l - values of the pointwise laplacian of f on the mth level in TLR order

g = ones(3^(m+1),1) ;
l = laplacian(f,g,m) ;